@@ -4,20 +4,13 @@
 #
 #	This widget both generates and reacts to DOM Events.
 #
-# Copyright (c) 1999-2002 Zveno Pty Ltd
+# Copyright (c) 1999-2003 Zveno Pty Ltd
 # http://www.zveno.com/
 #
-# Zveno makes this software and all associated data and documentation
-# ('Software') available free of charge for any purpose.
-# Copies may be made of this software but all of this notice must be included
-# on any copy.
+# See the file "LICENSE" in this distribution for information on usage and
+# redistribution of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 #
-# The software was developed for research purposes only and Zveno does not
-# warrant that it is error free or fit for any purpose.  Zveno disclaims any
-# liability for all claims, expenses, losses, damages and costs any user may
-# incur as a result of using, copying or modifying this software.
-#
-# $Id: domtext.tcl,v 1.2 2002/12/10 05:17:41 balls Exp $
+# $Id: domtext.tcl,v 1.5 2003/12/09 04:56:40 balls Exp $
 
 package provide domtext 2.5
 
@@ -210,18 +203,18 @@ proc domtext::configure {path args} {
 	set data(insert) 1.0
 
 	if {[string length $root]} {
-	    set docel [dom::libxml2::document cget $root -documentElement]
+	    set docel [dom::document cget $root -documentElement]
 
 	    if {[string length $docel]} {
 		# Listen for UI events
-		dom::libxml2::node addEventListener $root DOMActivate [namespace code [list _node_selected $path]] -usecapture 1
+		dom::node addEventListener $root DOMActivate [namespace code [list _node_selected $path]] -usecapture 1
 
 		# Listen for mutation events
-		dom::libxml2::node addEventListener $root DOMNodeInserted [namespace code [list _node_inserted $path]] -usecapture 1
-		dom::libxml2::node addEventListener $root DOMNodeRemoved [namespace code [list _node_removed $path]] -usecapture 1
-		dom::libxml2::node addEventListener $root DOMCharacterDataModified [namespace code [list _node_pcdata_modified $path]] -usecapture 1
-		dom::libxml2::node addEventListener $root DOMAttrModified [namespace code [list _node_attr_modified $path]] -usecapture 1
-		dom::libxml2::node addEventListener $root DOMAttrRemoved [namespace code [list _node_attr_removed $path]] -usecapture 1
+		dom::node addEventListener $root DOMNodeInserted [namespace code [list _node_inserted $path]] -usecapture 1
+		dom::node addEventListener $root DOMNodeRemoved [namespace code [list _node_removed $path]] -usecapture 1
+		dom::node addEventListener $root DOMCharacterDataModified [namespace code [list _node_pcdata_modified $path]] -usecapture 1
+		dom::node addEventListener $root DOMAttrModified [namespace code [list _node_attr_modified $path]] -usecapture 1
+		dom::node addEventListener $root DOMAttrRemoved [namespace code [list _node_attr_removed $path]] -usecapture 1
 
 		_refresh $path $root
 	    }
@@ -233,19 +226,19 @@ proc domtext::configure {path args} {
     set cc [Widget::hasChanged $path -commentcolor commcolor]
     set ec [Widget::hasChanged $path -entityrefcolor ercolor]
     set ebg [Widget::hasChanged $path -elementbgcolorlist ebgcolor]
-    if {$rn || $tc} {
+    if {($rn && [string length $root]) || $tc} {
 	$path.text tag configure tags -foreground $tagcolor
     }
-    if {$rn || $cc} {
+    if {($rn && [string length $root]) || $cc} {
 	$path.text tag configure comment -foreground $commcolor
     }
-    if {$rn || $ec} {
+    if {($rn && [string length $root]) || $ec} {
 	$path.text tag configure entityreference -foreground $ercolor
     }
-    if {$rn || $hc} {
+    if {($rn && [string length $root]) || $hc} {
 	$path.text tag configure highlight -background $hlcolor
     }
-    if {$rn || $ebg} {
+    if {($rn && [string length $root]) || $ebg} {
 	set data(nextElemBgColor) 0
 	_elementbg_setall $path $root
     }
@@ -345,7 +338,7 @@ proc domtext::_refresh {path node} {
 
     $path.text tag configure $node -background [_elementbg_cycle $path]
 
-    switch [::dom::libxml2::node cget $node -nodeType] {
+    switch [::dom::node cget $node -nodeType] {
 	document -
 	documentFragment {
 
@@ -361,7 +354,7 @@ proc domtext::_refresh {path node} {
 	    $path.text insert $data(insert) "<?xml[dom::Serialize:attributeList $xmldecllist]?>\n" [list $node xmldecl]
 	    set data(insert) [lindex [$path.text tag ranges $node] end]
 	}
-	    foreach childToken [::dom::libxml2::node children $node] {
+	    foreach childToken [::dom::node children $node] {
 		set end [_refresh $path $childToken]
 		set data(insert) $end
 	    }
@@ -374,7 +367,7 @@ proc domtext::_refresh {path node} {
 	element {
 
 	    # Serialize the start tag
-	    $path.text insert $data(insert) <[::dom::libxml2::node cget $node -nodeName] [list tags tag:start:$node] [::dom::Serialize:attributeList [array get [::dom::libxml2::node cget $node -attributes]]] [list tags attrs:$node] > [list tags tag:start:$node]
+	    $path.text insert $data(insert) <[::dom::node cget $node -nodeName] [list tags tag:start:$node] [_serialize:attributeList [array get [::dom::node cget $node -attributes]]] [list tags attrs:$node] > [list tags tag:start:$node]
 
 	    # Add the start tab icon
 	    $path.text image create $data(insert) -image ::domtext::starttab -align center -name tab:start:$node
@@ -387,14 +380,14 @@ proc domtext::_refresh {path node} {
 	    # Serialize the content
 	    $path.text mark set content:$node $data(insert)
 	    $path.text mark gravity content:$node left
-	    foreach childToken [::dom::libxml2::node children $node] {
+	    foreach childToken [::dom::node children $node] {
 		set end [_refresh $path $childToken]
 		set data(insert) $end
 	    }
 	    $path.text tag add content:$node content:$node $end
 
 	    # Serialize the end tag
-	    $path.text insert $data(insert) </[::dom::libxml2::node cget $node -nodeName]> [list tags tag:end:$node]
+	    $path.text insert $data(insert) </[::dom::node cget $node -nodeName]> [list tags tag:end:$node]
 	    set end [lindex [$path.text tag ranges tag:end:$node] end]
 	    # Add the end tab icon
 	    $path.text image create $end -image ::domtext::endtab -align center -name tab:end:$node
@@ -414,7 +407,7 @@ proc domtext::_refresh {path node} {
 	}
 
 	textNode {
-	    set text [::dom::Serialize:textNode $node]
+	    set text [_encode [dom::node cget $node -nodeValue]]
 	    if {[string length $text]} {
 		$path.text insert $data(insert) $text $node
 		set end [lindex [$path.text tag ranges $node] 1]
@@ -442,25 +435,25 @@ proc domtext::_refresh {path node} {
 	}
 
 	comment {
-	    set text [::dom::libxml2::node cget $node -nodeValue]
+	    set text [::dom::node cget $node -nodeValue]
 	    $path.text insert $data(insert) <!-- [list comment markup $node] $text [list comment $node] --> [list comment markup $node]
 	    set end [lindex [$path.text tag ranges $node] 1]
 	    set data(insert) $end
 	}
 
 	entityReference {
-	    set text [::dom::libxml2::node cget $node -nodeName]
+	    set text [::dom::node cget $node -nodeName]
 	    $path.text insert $data(insert) & [list entityreference markup $node] $text [list entityreference $node] \; [list entityreference markup $node]
 	    set end [lindex [$path.text tag ranges $node] 1]
 	    set data(insert) $end
 	}
 
 	processingInstruction {
-	    set text [::dom::libxml2::node cget $node -nodeValue]
+	    set text [::dom::node cget $node -nodeValue]
 	    if {[string length $text]} {
 		set text " $text"
 	    }
-	    $path.text insert $data(insert) "<?[::dom::libxml2::node cget $node -nodeName]$text?>" $node
+	    $path.text insert $data(insert) "<?[::dom::node cget $node -nodeName]$text?>" $node
 	    set end [lindex [$path.text tag ranges $node] 1]
 	    set data(insert) $end
 	}
@@ -474,6 +467,71 @@ proc domtext::_refresh {path node} {
     return $end
 }
 
+# domtext::_serialize:attributeList --
+#
+#	Produce textual representation of an attribute list.
+#
+#	NB. This is copied from TclDOM's domimpl.tcl,
+#	but with the namespace handling removed.
+#
+# Arguments:
+#	atlist	name/value list of attributes
+#
+# Results:
+#	Returns string
+
+proc domtext::_serialize:attributeList atlist {
+
+    set result {}
+    foreach {name value} $atlist {
+
+	append result { } $name =
+
+	# Handle special characters
+	regsub -all & $value {\&amp;} value
+	regsub -all < $value {\&lt;} value
+
+	if {![string match *\"* $value]} {
+	    append result \"$value\"
+	} elseif {![string match *'* $value]} {
+	    append result '$value'
+	} else {
+	    regsub -all \" $value {\&quot;} value
+	    append result \"$value\"
+	}
+
+    }
+
+    return $result
+}
+
+# domtext::_encode --
+#
+#	Protect XML special characters
+#
+#	NB. This is copied from TclDOM's domimpl.tcl.
+#
+# Arguments:
+#	value	text
+#
+# Results:
+#	Returns string
+
+proc domtext::_encode value {
+    array set Entity {
+	$ $
+	< &lt;
+	> &gt;
+	& &amp;
+	\" &quot;
+	' &apos;
+    }
+
+    regsub -all {([$<>&"'])} $value {$Entity(\1)} value
+
+    return [subst -nocommand -nobackslash $value]
+}
+
 # domtext::_elementbg_setall --
 #
 #	Recurse node hierarchy setting element background color property
@@ -489,11 +547,11 @@ proc domtext::_elementbg_setall {path node} {
 
     $path.text tag configure $node -background [_elementbg_cycle $path]
 
-    switch [dom::libxml2::node cget $node -nodeType] {
+    switch [dom::node cget $node -nodeType] {
 	document -
 	documentFragment -
 	element {
-	    foreach child [dom::libxml2::node children $node] {
+	    foreach child [dom::node children $node] {
 		_elementbg_setall $path $child
 	    }
 	}
@@ -529,10 +587,10 @@ proc domtext::_elementbg_cycle path {
 proc domtext::_node_inserted {path evid} {
     upvar #0 [namespace current]::$path data
 
-    set node [dom::libxml2::event cget $evid -target]
+    set node [dom::event cget $evid -target]
 
     # Remove parent's content and then render new content
-    set parent [dom::libxml2::node parent $node]
+    set parent [dom::node parent $node]
     set tags [$path.text tag ranges $parent]
     set start [lindex $tags 0]
     set end [lindex $tags end]
@@ -546,19 +604,19 @@ proc domtext::_node_inserted {path evid} {
     set end [_refresh $path $parent]
 
     # Restore grandparent element tags
-    set parent [::dom::libxml2::node parent $parent]
+    set parent [::dom::node parent $parent]
     while {[string length $parent]} {
 	set ranges [$path.text tag ranges $parent]
 	catch {eval [list $path.text] tag remove [list $parent] $ranges}
 	catch {$path.text tag add $parent [lindex $ranges 0] [lindex $ranges end]}
 	# Also do content tag for elements
-	if {![string compare [::dom::libxml2::node cget $parent -nodeType] "element"]} {
+	if {![string compare [::dom::node cget $parent -nodeType] "element"]} {
 	    set ranges [$path.text tag ranges content:$parent]
 	    catch {eval [list $path.text] tag remove [list $parent] $ranges}
 	    catch {$path.text tag add content:$parent [lindex $ranges 0] [lindex $ranges end]}
 	}
 
-	set parent [::dom::libxml2::node parent $parent]
+	set parent [::dom::node parent $parent]
     }
 
     return {}
@@ -580,14 +638,14 @@ proc domtext::_node_inserted {path evid} {
 proc domtext::_node_removed {path evid} {
     upvar #0 [namespace current]::selected$path selected
 
-    set node [dom::libxml2::event cget $evid -target]
+    set node [dom::event cget $evid -target]
 
     if {[info exists selected] && ![string compare $node $selected]} {
 	unset selected
     }
 
     # Remove parent's content and then render new content
-    set parent [dom::libxml2::event cget $evid -relatedNode]
+    set parent [dom::event cget $evid -relatedNode]
     set tags [$path.text tag ranges $parent]
     set start [lindex $tags 0]
     set end [lindex $tags end]
@@ -601,19 +659,19 @@ proc domtext::_node_removed {path evid} {
     set end [_refresh $path $parent]
 
     # Restore grandparent element tags
-    set parent [::dom::libxml2::node parent $parent]
+    set parent [::dom::node parent $parent]
     while {[string length $parent]} {
 	set ranges [$path.text tag ranges $parent]
 	catch {eval [list $path.text] tag remove [list $parent] $ranges}
 	catch {$path.text tag add $parent [lindex $ranges 0] [lindex $ranges end]}
 	# Also do content tag for elements
-	if {![string compare [::dom::libxml2::node cget $parent -nodeType] "element"]} {
+	if {![string compare [::dom::node cget $parent -nodeType] "element"]} {
 	    set ranges [$path.text tag ranges content:$parent]
 	    catch {eval [list $path.text] tag remove [list $parent] $ranges}
 	    catch {$path.text tag add content:$parent [lindex $ranges 0] [lindex $ranges end]}
 	}
 
-	set parent [::dom::libxml2::node parent $parent]
+	set parent [::dom::node parent $parent]
     }
 
     return {}
@@ -632,7 +690,7 @@ proc domtext::_node_removed {path evid} {
 
 proc domtext::_node_attr_modified {path evid} {
 
-    set node [dom::libxml2::event cget $evid -target]
+    set node [dom::event cget $evid -target]
 
     set tags [$path.text tag ranges attrs:$node]
     if {[llength $tags]} {
@@ -653,7 +711,7 @@ proc domtext::_node_attr_modified {path evid} {
     # Replace with current attributes
 
     lappend existingTags attrs:$node
-    $path.text insert $start [::dom::Serialize:attributeList [array get [::dom::libxml2::node cget $node -attributes]]] $existingTags
+    $path.text insert $start [::dom::Serialize:attributeList [array get [::dom::node cget $node -attributes]]] $existingTags
 
     return {}
 }
@@ -686,9 +744,9 @@ proc domtext::_node_attr_removed {path evid} {
 
 proc domtext::_node_pcdata_modified {path evid} {
 
-    set node [dom::libxml2::event cget $evid -target]
+    set node [dom::event cget $evid -target]
 
-    if {[string compare [dom::libxml2::node cget $node -nodeType] "textNode"]} {
+    if {[string compare [dom::node cget $node -nodeType] "textNode"]} {
 	return -code error "node is not a text node"
     }
 
@@ -701,7 +759,7 @@ proc domtext::_node_pcdata_modified {path evid} {
     eval [list $path.text] delete $ranges
 
     # Replace with new text
-    $path.text insert [lindex $ranges 0] [dom::libxml2::event cget $evid -newValue] $tags
+    $path.text insert [lindex $ranges 0] [dom::event cget $evid -newValue] $tags
 
     # Restore insertion point
     $path.text mark set insert $insert
@@ -723,7 +781,7 @@ proc domtext::_node_pcdata_modified {path evid} {
 proc domtext::_node_selected {path evid} {
     upvar #0 [namespace current]::selected$path selected
 
-    set node [dom::libxml2::event cget $evid -target]
+    set node [dom::event cget $evid -target]
     set selected $node
 
     catch {eval [list $path.text] tag remove sel [$path.text tag ranges sel]}
@@ -772,9 +830,9 @@ proc domtext::_tkevent_select {path node x y} {
 
     catch {after cancel $tkeventid}
     set tkeventid [after idle "
-    dom::libxml2::event postUIEvent [list $node] DOMActivate -detail 1
-    dom::libxml2::event postMouseEvent [list $node] click -detail 1
-    [namespace current]::_tkevent_select_setinsert [list $path] [list $node] [tkTextClosestGap $path.text $x $y]
+    dom::event postUIEvent [list $node] DOMActivate -detail 1
+    dom::event postMouseEvent [list $node] click -detail 1
+    [namespace current]::_tkevent_select_setinsert [list $path] [list $node] [::tk::TextClosestGap $path.text $x $y]
 "]
     return {}
 }
@@ -782,7 +840,7 @@ proc domtext::_tkevent_select {path node x y} {
 # Helper routine for above proc
 
 proc domtext::_tkevent_select_setinsert {path node idx} {
-    switch [::dom::libxml2::node cget $node -nodeType] {
+    switch [::dom::node cget $node -nodeType] {
 	textNode {
 	    # No need to change where the insertion point is going
 	}
@@ -790,8 +848,8 @@ proc domtext::_tkevent_select_setinsert {path node idx} {
 	    # Set the insertion point to the end of the first
 	    # child textNode, or if none to immediately following
 	    # the start tag.
-	    set fc [::dom::libxml2::node cget $node -firstChild]
-	    if {[string length $fc] && [::dom::libxml2::node cget $fc -nodeType] == "textNode"} {
+	    set fc [::dom::node cget $node -firstChild]
+	    if {[string length $fc] && [::dom::node cget $fc -nodeType] == "textNode"} {
 		set idx [lindex [$path.text tag ranges $fc] end]
 	    } else {
 		set idx [lindex [$path.text tag ranges tag:start:$node] end]
@@ -826,8 +884,8 @@ proc domtext::_tkevent_open {path node} {
 
     catch {after cancel $tkeventid}
     set tkeventid [after idle "
-    dom::libxml2::event postUIEvent [list $node] DOMActivate -detail 2
-    dom::libxml2::event postMouseEvent [list $node] click -detail 2
+    dom::event postUIEvent [list $node] DOMActivate -detail 2
+    dom::event postMouseEvent [list $node] click -detail 2
 "]
     return {}
 }
@@ -857,20 +915,20 @@ proc domtext::_key_select {path spec} {
     # Otherwise markup has been selected.
     # Move around the nodes
 
-    switch -glob [dom::libxml2::node cget $selected -nodeType],$spec {
+    switch -glob [dom::node cget $selected -nodeType],$spec {
 	textNode,<Key-Up> {
 	    set ranges [$path.text tag ranges $selected]
 	    foreach {line char} [split [lindex $ranges 0] .] break
 	    set index [$path.text index insert]
 	    foreach {iline ichar} [split [lindex $index 0] .] break
 	    if {$line == $iline} {
-		set new [dom::libxml2::node parent $selected]
+		set new [dom::node parent $selected]
 	    } else {
-		tkTextSetCursor $path.text [tkTextUpDownLine $path.text -1]
+		::tk::TextSetCursor $path.text [::tk::TextUpDownLine $path.text -1]
 		# The insertion point may now be in another node
 		set newnode [_insert_to_node $path]
 		if {[string compare $newnode $selected]} {
-		    dom::libxml2::event postUIEvent $newnode DOMActivate -detail 1
+		    dom::event postUIEvent $newnode DOMActivate -detail 1
 		}
 		return -code break
 	    }
@@ -884,11 +942,11 @@ proc domtext::_key_select {path spec} {
 		bell
 		return {}
 	    } else {
-		tkTextSetCursor $path.text [tkTextUpDownLine $path.text 1]
+		::tk::TextSetCursor $path.text [::tk::TextUpDownLine $path.text 1]
 		# The insertion point may now be in another node
 		set newnode [_insert_to_node $path]
 		if {[string compare $newnode $selected]} {
-		    dom::libxml2::event postUIEvent $newnode DOMActivate -detail 1
+		    dom::event postUIEvent $newnode DOMActivate -detail 1
 		}
 		return -code break
 	    }
@@ -897,12 +955,12 @@ proc domtext::_key_select {path spec} {
 	    set ranges [$path.text tag ranges $selected]
 	    set index [$path.text index insert]
 	    if {[$path.text compare $index == [lindex $ranges 0]]} {
-		set new [dom::libxml2::node cget $selected -previousSibling]
+		set new [dom::node cget $selected -previousSibling]
 		if {![string length $new]} {
-		    set new [dom::libxml2::node parent $selected]
+		    set new [dom::node parent $selected]
 		}
 	    } else {
-		tkTextSetCursor $path.text insert-1c
+		::tk::TextSetCursor $path.text insert-1c
 		return -code break
 	    }
 	}
@@ -910,40 +968,40 @@ proc domtext::_key_select {path spec} {
 	    set ranges [$path.text tag ranges $selected]
 	    set index [$path.text index insert]
 	    if {[$path.text compare $index == [lindex $ranges end]]} {
-		set new [dom::libxml2::node cget $selected -nextSibling]
+		set new [dom::node cget $selected -nextSibling]
 		if {![string length $new]} {
-		    set new [dom::libxml2::node parent $selected]
+		    set new [dom::node parent $selected]
 		}
 	    } else {
-		tkTextSetCursor $path.text insert+1c
+		::tk::TextSetCursor $path.text insert+1c
 		return -code break
 	    }
 	}
 
 	*,<Key-Up>	{
-	    set new [dom::libxml2::node parent $selected]
+	    set new [dom::node parent $selected]
 	}
 	*,<Key-Down>	{
-	    set new [dom::libxml2::node cget $selected -firstChild]
+	    set new [dom::node cget $selected -firstChild]
 	    if {![string length $new]} {
 		bell
 		return {}
 	    }
 	}
 	*,<Key-Left>	{
-	    if {[dom::libxml2::node parent $selected] == $root} {
+	    if {[dom::node parent $selected] == $root} {
 		bell
 		return {}
 	    }
-	    set new [dom::libxml2::node cget $selected -previousSibling]
+	    set new [dom::node cget $selected -previousSibling]
 	    if {![string length $new]} {
-		set new [dom::libxml2::node parent $selected]
+		set new [dom::node parent $selected]
 	    }
 	}
 	*,<Key-Right>	{
-	    set new [dom::libxml2::node cget $selected -nextSibling]
+	    set new [dom::node cget $selected -nextSibling]
 	    if {![string length $new]} {
-		set new [dom::libxml2::node parent $selected]
+		set new [dom::node parent $selected]
 	    }
 	}
     }
@@ -951,7 +1009,7 @@ proc domtext::_key_select {path spec} {
 	bell
     }
 
-    dom::libxml2::event postUIEvent $new DOMActivate -detail 1
+    dom::event postUIEvent $new DOMActivate -detail 1
 
     return -code break
 }
@@ -992,14 +1050,14 @@ proc domtext::_tkevent_filter_<Key> {path detail} {
     #	Document Type Declaration	ignore
     #	XML Declaration			ignore
 
-    switch [dom::libxml2::node cget $selected -nodeType] {
+    switch [dom::node cget $selected -nodeType] {
 	element {
-	    set child [dom::libxml2::node cget $selected -firstChild]
+	    set child [dom::node cget $selected -firstChild]
 	    if {[string length $child]} {
-		if {[dom::libxml2::node cget $child -nodeType] == "textNode"} {
-		    dom::libxml2::event postUIEvent $child DOMActivate -detail 1
-		    dom::libxml2::node configure $child -nodeValue [dom::libxml2::node cget $child -nodeValue]$detail
-		    tkTextSetCursor $path.text insert+1c
+		if {[dom::node cget $child -nodeType] == "textNode"} {
+		    dom::event postUIEvent $child DOMActivate -detail 1
+		    dom::node configure $child -nodeValue [dom::node cget $child -nodeValue]$detail
+		    ::tk::TextSetCursor $path.text insert+1c
 		    focus $path.text
 		    return -code $code {}
 		} else {
@@ -1007,8 +1065,8 @@ proc domtext::_tkevent_filter_<Key> {path detail} {
 		    return -code $code {}
 		}
 	    } else {
-		set child [dom::libxml2::document createTextNode $selected $detail]
-		dom::libxml2::event postUIEvent $child DOMActivate -detail 1
+		set child [dom::document createTextNode $selected $detail]
+		dom::event postUIEvent $child DOMActivate -detail 1
 		# When we return the new text node will have been
 		# inserted into the Text widget
 		set end [lindex [$path.text tag ranges $child] 1]
@@ -1030,7 +1088,7 @@ proc domtext::_tkevent_filter_<Key> {path detail} {
 	    focus $path.text
 	    set ranges [$path.text tag ranges $selected]
 	    set newvalue [$path.text get [lindex $ranges 0] [lindex $ranges end]]
-	    dom::libxml2::node configure $selected -nodeValue $newvalue
+	    dom::node configure $selected -nodeValue $newvalue
 	    return -code $code {}
 
 	}
@@ -1068,7 +1126,7 @@ proc domtext::_tkevent_filter_<Key-BackSpace> {path detail} {
     }
     upvar #0 [namespace current]::selected$path selected
 
-    switch [dom::libxml2::node cget $selected -nodeType] {
+    switch [dom::node cget $selected -nodeType] {
 	textNode {
 	    # If we're at the beginning of the text node stop here
 	    set ranges [$path.text tag ranges $selected]
@@ -1078,9 +1136,9 @@ proc domtext::_tkevent_filter_<Key-BackSpace> {path detail} {
 	    }
 	}
 	default {
-	    switch [tk_messageBox -parent [winfo toplevel $path] -title [mc {Confirm Delete Node}] -message [format [mc {Are you sure you want to delete a node of type %s?}] [dom::libxml2::node cget $selected -nodeType]] -type okcancel] {
+	    switch [tk_messageBox -parent [winfo toplevel $path] -title [mc {Confirm Delete Node}] -message [format [mc {Are you sure you want to delete a node of type %s?}] [dom::node cget $selected -nodeType]] -type okcancel] {
 		ok {
-		    dom::libxml2::node removeNode [dom::libxml2::node parent $selected] $selected
+		    dom::node removeNode [dom::node parent $selected] $selected
 		}
 		cancel {
 		    return -code break
@@ -1104,7 +1162,7 @@ proc domtext::_tkevent_filter_<Key-Delete> {path detail} {
     }
     upvar #0 [namespace current]::selected$path selected
 
-    switch [dom::libxml2::node cget $selected -nodeType] {
+    switch [dom::node cget $selected -nodeType] {
 	textNode {
 	    # If we're at the beginning of the text node stop here
 	    set ranges [$path.text tag ranges $selected]
@@ -1114,9 +1172,9 @@ proc domtext::_tkevent_filter_<Key-Delete> {path detail} {
 	    }
 	}
 	default {
-	    switch [tk_messageBox -parent [winfo toplevel $path] -title [mc {Confirm Delete Node}] -message [format [mc {Are you sure you want to delete a node of type %s?}] [dom::libxml2::node cget $selected -nodeType]] -type okcancel] {
+	    switch [tk_messageBox -parent [winfo toplevel $path] -title [mc {Confirm Delete Node}] -message [format [mc {Are you sure you want to delete a node of type %s?}] [dom::node cget $selected -nodeType]] -type okcancel] {
 		ok {
-		    dom::libxml2::node removeNode [dom::libxml2::node parent $selected] $selected
+		    dom::node removeNode [dom::node parent $selected] $selected
 		}
 		cancel {
 		    return -code break
@@ -1142,13 +1200,13 @@ proc domtext::_tkevent_filter_update path {
     # If all text has been deleted then remove the node
     if {[llength $ranges]} {
 	set newtext [$path.text get [lindex $ranges 0] [lindex $ranges end]]
-	dom::libxml2::node configure $selected -nodeValue $newtext
+	dom::node configure $selected -nodeValue $newtext
     } else {
-	set parent [dom::libxml2::node parent $selected]
-	dom::libxml2::node removeNode [dom::libxml2::node parent $selected] $selected
+	set parent [dom::node parent $selected]
+	dom::node removeNode [dom::node parent $selected] $selected
 	# Move selection to parent element, rather than removing selection
 	#unset selected
-	dom::libxml2::event postUIEvent $parent DOMActivate -detail 1
+	dom::event postUIEvent $parent DOMActivate -detail 1
     }
 
     return {}
